@@ -35,7 +35,7 @@ struct Convert      // if there's just one ReturnType operator()(...), simply
 
     string operator()(double x) const
     {
-        return string("hello world");
+        return "hello world"s;
     }
     template <typename Class>
     struct result<Class(double)>
